pub struct RcuCache<K, V, S = RapidBuildHasher>where
K: Eq + Hash + Clone + Send + Sync + 'static,
V: Clone + Send + Sync + 'static,
S: BuildHasher + Send + Sync + 'static,{ /* private fields */ }Expand description
A cache that uses RCU to provide thread-safe access to a hash map.
This is similar to RcuHashMap, but it also evicts items when the cache
exceeds a specified capacity.
Entries are evicted in a FIFO manner.
By default, this map uses rapidhash::RapidBuildHasher, which provides high performance.
However, if this map holds keys which may be attacker-controlled, consider using
std::collections::hash_map::RandomState instead.
Implementations
Sourceimpl<K, V> RcuCache<K, V, RapidBuildHasher>
impl<K, V> RcuCache<K, V, RapidBuildHasher>
Sourceimpl<K, V, S> RcuCache<K, V, S>
impl<K, V, S> RcuCache<K, V, S>
Sourcepub fn with_capacity_and_hasher(capacity: usize, hash_builder: S) -> Self
pub fn with_capacity_and_hasher(capacity: usize, hash_builder: S) -> Self
Creates a new RcuCache with the specified capacity and hasher.