pub enum Entry<'b, 'a, K, V, S = RapidBuildHasher>where
K: Eq + Hash + Clone + Send + Sync + 'static,
V: Clone + Send + Sync + 'static,
S: BuildHasher + Send + Sync + 'static,{
Occupied(OccupiedEntry<'b, 'a, K, V, S>),
Vacant(VacantEntry<'b, 'a, K, V, S>),
}Expand description
A view into a single entry in the map, which may either be vacant or occupied.
Variants
Occupied(OccupiedEntry<'b, 'a, K, V, S>)
An occupied entry.
Vacant(VacantEntry<'b, 'a, K, V, S>)
A vacant entry.
Implementations
Sourceimpl<'b, 'a, K, V, S> Entry<'b, 'a, K, V, S>
impl<'b, 'a, K, V, S> Entry<'b, 'a, K, V, S>
Sourcepub fn or_insert_with<F: FnOnce() -> V>(
self,
default: F,
) -> OccupiedEntry<'b, 'a, K, V, S>
pub fn or_insert_with<F: FnOnce() -> V>( self, default: F, ) -> OccupiedEntry<'b, 'a, K, V, S>
Ensures a value is in the entry by inserting the result of the default function if empty, and returns an occupied entry.