pub struct RcuHashMapGuard<'a, K, V, S = RapidBuildHasher>where
K: Eq + Hash + Clone + Send + Sync + 'static,
V: Clone + Send + Sync + 'static,
S: BuildHasher + Send + Sync + 'static,{ /* private fields */ }Expand description
A guard that provides exclusive access to the RcuHashMap.
Implementations
Sourceimpl<'a, K, V, S> RcuHashMapGuard<'a, K, V, S>
impl<'a, K, V, S> RcuHashMapGuard<'a, K, V, S>
Sourcepub fn get<Q>(&self, key: &Q) -> Option<V>
pub fn get<Q>(&self, key: &Q) -> Option<V>
Returns a copy (clone) of the value associated with the given key, if it exists.
Sourcepub fn drain<'b>(&'b mut self) -> impl Iterator<Item = (K, V)> + 'b
pub fn drain<'b>(&'b mut self) -> impl Iterator<Item = (K, V)> + 'b
Removes all values from the map and returns them.
Sourcepub fn contains_key<Q>(&self, key: &Q) -> bool
pub fn contains_key<Q>(&self, key: &Q) -> bool
Returns true if the map contains a value for the specified key.