pub struct VacantEntry<'b, 'a, K, V, S = RapidBuildHasher>where
K: Eq + Hash + Clone + Send + Sync + 'static,
V: Clone + Send + Sync + 'static,
S: BuildHasher + Send + Sync + 'static,{ /* private fields */ }Expand description
A view into a vacant entry in a RcuHashMap.
Implementations
Sourceimpl<'b, 'a, K, V, S> VacantEntry<'b, 'a, K, V, S>
impl<'b, 'a, K, V, S> VacantEntry<'b, 'a, K, V, S>
Sourcepub fn insert_entry(self, value: V) -> OccupiedEntry<'b, 'a, K, V, S>
pub fn insert_entry(self, value: V) -> OccupiedEntry<'b, 'a, K, V, S>
Sets the value of the entry with the VacantEntry’s key, and returns an occupied entry.