pub struct RcuAtomic<T: AsAtomic> { /* private fields */ }Implementations
Sourceimpl<T: AsAtomic> RcuAtomic<T>
impl<T: AsAtomic> RcuAtomic<T>
pub fn new(value: T) -> Self
Sourcepub fn write(&self, value: T)
pub fn write(&self, value: T)
Basic write operation: takes the mutex and updates both the mutex value and the atomic.
Sourcepub fn copy(&self) -> RcuAtomicGuard<'_, T>
pub fn copy(&self) -> RcuAtomicGuard<'_, T>
Takes the mutex and returns a guard that can be used to read and modify the value.
Updates are only committed to the atomic when update is called on the guard.