pub struct RcuReadScope { /* private fields */ }Expand description
A scope that holds a read lock on the RCU state machine.
This scope is used to ensure that the object referenced by the pointer remains valid until the scope is dropped.
Implementations
Sourceimpl RcuReadScope
impl RcuReadScope
Sourcepub fn new() -> RcuReadScope
pub fn new() -> RcuReadScope
Create a new read scope.
This function acquires a read lock on the RCU state machine. The read lock is held until the scope is dropped.